@@ -1,6 +1,7 @@
 import copy
 import math
 import os
+import random
 import re
 import sys
 import string
@@ -25,8 +26,8 @@ def AutoSpearman(X_train, correlation_threshold=0.7, correlation_method='spearma
 
     Parameters
     ----------
-    X_train : :obj:``
-        Threshold value of correalation.
+    X_train : :obj:`pd.core.frame.DataFrame`
+        The X_train data to be processed
     correlation_threshold : :obj:`float`
         Threshold value of correalation.
     correlation_method : :obj:`str`
@@ -122,8 +123,15 @@ def AutoSpearman(X_train, correlation_threshold=0.7, correlation_method='spearma
         selected_features = list(set(selected_features) - set([metric_to_exclude]))
 
         X_AS_train = X_AS_train.loc[:, selected_features]
+
     print('Finally, according to Part 2 of AutoSpearman,', AS_metrics, 'are selected.')
-    return X_AS_train
+    all_cols = X_train.columns
+    for col in all_cols:
+        if col not in list(AS_metrics):
+            all_cols = all_cols.drop(col)
+    selected = all_cols
+    X_train = X_train.loc[:, selected]
+    return X_train
 
 
 def get_base_prefix_compat():
@@ -561,10 +569,14 @@ class PyExplainer:
             "importance", ascending=False).head(top_k)
         top_k_positive_rules['Class'] = self.class_label[1]
         top_k_positive_rules = positive_filtered_rules.reset_index()
+        # filter out nan values
+        top_k_positive_rules = top_k_positive_rules.dropna()
 
         # negative rules
         top_k_negative_rules = rules.loc[rules['coef'] < 0].sort_values("importance", ascending=False).head(top_k)
         top_k_negative_rules['Class'] = self.class_label[0]
+        # filter out nan values
+        top_k_negative_rules = top_k_negative_rules.dropna()
 
         rule_obj = {'synthetic_data': synthetic_instances,
                     'synthetic_predictions': synthetic_predictions,
